@@ -24,6 +24,8 @@ void help(int exitCode)
     "Options:\n"
     "\n"
     "  -d, --deleglise-rivat    Count primes using the Deleglise-Rivat algorithm\n"
+    "      --double-check       Recompute pi(x) with alternative alpha tuning\n"
+    "                           factor(s) to verify the first result.\n"
     "  -g, --gourdon            Count primes using Xavier Gourdon's algorithm.\n"
     "                           This is the default algorithm.\n"
     "  -l, --legendre           Count primes using Legendre's formula\n"
