@@ -248,15 +248,18 @@ int64_t pi_lmo_parallel(int64_t x,
   auto lpf = generate_lpf(y);
   auto mu = generate_moebius(y);
 
+  int64_t Lix = Li(x);
   int64_t pi_y = primes.size() - 1;
   int64_t p2 = P2(x, y, pi_y, threads, is_print);
   int64_t s1 = S1(x, y, c, threads, is_print);
-  int64_t s2_approx = S2_approx(x, pi_y, p2, s1);
+  int64_t s2_approx = S2_approx(Lix, pi_y, p2, s1);
   int64_t s2 = S2(x, y, z, c, s2_approx, primes, lpf, mu, threads, is_print);
   int64_t phi = s1 + s2;
-  int64_t sum = phi + pi_y - 1 - p2;
+  int64_t pix = phi + pi_y - 1 - p2;
 
-  return sum;
+  verify_pix("pi_lmo_parallel", x, pix, Lix);
+
+  return pix;
 }
 
 } // namespace
