@@ -3,7 +3,7 @@
 ///        This file contains helper functions and global variables
 ///        that are initialized with default settings.
 ///
-/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -20,6 +20,9 @@
 #include <algorithm>
 #include <chrono>
 #include <cmath>
+#include <cstdlib>
+#include <iostream>
+#include <sstream>
 #include <string>
 #include <stdint.h>
 #include <utility>
@@ -28,21 +31,29 @@ namespace {
 
 int status_precision_ = -1;
 
-// Tuning factor used in the Lagarias-Miller-Odlyzko
-// and Deleglise-Rivat algorithms.
+/// Tuning factor used in the Lagarias-Miller-Odlyzko
+/// and Deleglise-Rivat algorithms.
 double alpha_ = -1;
 
-// Tuning factor used in Xavier Gourdon's algorithm
+/// Tuning factor used in Xavier Gourdon's algorithm
 double alpha_y_ = -1;
 
-// Tuning factor used in Xavier Gourdon's algorithm
+/// Tuning factor used in Xavier Gourdon's algorithm
 double alpha_z_ = -1;
 
+/// Recompute pi(x) with alternative alpha tuning factor(s) to
+/// verify the first result. This redundancy helps guard
+/// against potential bugs in primecount: if an error exists,
+/// it is highly unlikely that both pi(x) computations would
+/// produce the same (incorrect) result.
+///
+bool double_check_ = false;
+
 /// Truncate a floating point number to 3 digits after the decimal
-/// point. This function is used limit the number of digits after the
-/// decimal point of the alpha tuning factor in order to make it more
-/// convenient for the user to e.g. type the alpha tuning factor as
-/// a command-line parameter.
+/// point. This function is used limit the number of digits after
+/// the decimal point of the alpha tuning factor in order to make
+/// it more convenient for the user to e.g. type the alpha tuning
+/// factor as a command-line parameter.
 ///
 double truncate3(double n)
 {
@@ -161,6 +172,11 @@ double get_time()
   return (double) micro.count() / 1e6;
 }
 
+void set_double_check(bool enable)
+{
+  double_check_ = enable;
+}
+
 void set_alpha(double alpha)
 {
   // If alpha < 1 then we compute a good
@@ -261,6 +277,11 @@ double get_alpha_lmo(maxint_t x)
     alpha = a * logx2 + b * logx + c;
   }
 
+  // Recompute pi(x) with alternative alpha tuning
+  // factor(s) to verify the first result.
+  if (double_check_)
+    alpha *= 0.97;
+
   // Preserve 3 digits after decimal point
   alpha = in_between(1, alpha, x16);
   alpha = truncate3(alpha);
@@ -304,6 +325,11 @@ double get_alpha_deleglise_rivat(maxint_t x)
     }
   }
 
+  // Recompute pi(x) with alternative alpha tuning
+  // factor(s) to verify the first result.
+  if (double_check_)
+    alpha *= 0.97;
+
   // Preserve 3 digits after decimal point
   alpha = in_between(1, alpha, x16);
   alpha = truncate3(alpha);
@@ -381,6 +407,13 @@ std::pair<double, double> get_alpha_gourdon(maxint_t x)
     alpha_z = in_between(1, alpha_yz / 5, alpha_z);
   }
 
+  // --double-check option for second pi(x) computation
+  if (double_check_)
+  {
+    alpha_z = max(1.0, alpha_z * 1.02);
+    alpha_yz = max(1.0, alpha_yz * 0.97);
+  }
+
   // Use default alpha_y
   if (alpha_y < 1)
     alpha_y = alpha_yz / alpha_z;
@@ -435,4 +468,39 @@ int64_t get_x_star_gourdon(maxint_t x, int64_t y)
   return x_star;
 }
 
+/// Quickly verify a pi(x) result.
+/// Note that this check can only detect miscalculations if the
+/// pi(x) result if off by >= sqrt(x) * log(x) / 8π.
+///
+/// Since we have an extensive test suite that likely finds most
+/// implementation bugs, we expect this verification check to
+/// mainly detect miscalculations due to hardware errors, such as
+/// malfunctioning RAM sticks or PC overclocking issues.
+///
+void verify_pix(string_view_t pix_function,
+                maxint_t x,
+                maxint_t pix,
+                maxint_t Lix)
+{
+  if (x < 2657)
+    return;
+
+  double logx = std::log(x);
+  double sqrtx = std::sqrt(x);
+  constexpr double PI = 3.14159265358979323846;
+
+  // Lowell Schoenfeld, "Sharper bounds for the Chebyshev functions
+  // 𝜃(𝑥) and 𝜓(𝑥). II", Math. Comp., v. 30, 1976.
+  if (std::abs(double(pix - Lix)) >= (sqrtx * logx) / (8 * PI))
+  {
+    std::ostringstream oss;
+    oss << "\rprimecount error: " << pix_function << "(" << x << ") = " << pix << std::endl
+        << "Li(x) = " << Lix << ", sqrt(x) = " << sqrtx << ", log(x) = " << logx << std::endl
+        << "Assertion failed: |pi(x) - Li(x)| < sqrt(x) * log(x) / (8 * PI)" << std::endl
+        << std::endl;
+    std::cerr << oss.str() << std::flush;
+    std::abort();
+  }
+}
+
 } // namespace
