@@ -2,7 +2,7 @@
 /// @file   min.cpp
 /// @brief  Test min() and max() functions.
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -29,23 +29,23 @@ void check(bool OK)
 
 int main()
 {
-  static_assert(!is_comparable<int64_t, double>::value, 
-                "is_comparable<int64_t, double> is broken");
+  static_assert(!is_comparable_int<int64_t, double>::value, 
+                "is_comparable_int<int64_t, double> is broken");
 
-  static_assert(is_comparable<int64_t, int64_t>::value, 
-                "is_comparable<int64_t, int64_t> is broken");
+  static_assert(is_comparable_int<int64_t, int64_t>::value, 
+                "is_comparable_int<int64_t, int64_t> is broken");
 
-  static_assert(is_comparable<uint64_t, int64_t>::value, 
-                "is_comparable<uint64_t, int64_t> is broken");
+  static_assert(is_comparable_int<uint64_t, int64_t>::value, 
+                "is_comparable_int<uint64_t, int64_t> is broken");
 
-  static_assert(is_comparable<int64_t, int8_t>::value, 
-                "is_comparable<int64_t, int8_t> is broken");
+  static_assert(is_comparable_int<int64_t, int8_t>::value, 
+                "is_comparable_int<int64_t, int8_t> is broken");
 
-  static_assert(is_comparable<uint64_t, uint8_t>::value, 
-                "is_comparable<uint64_t, uint8_t> is broken");
+  static_assert(is_comparable_int<uint64_t, uint8_t>::value, 
+                "is_comparable_int<uint64_t, uint8_t> is broken");
 
-  static_assert(!is_comparable<int8_t, int64_t>::value, 
-                "is_comparable<int8_t, int64_t> is broken");
+  static_assert(!is_comparable_int<int8_t, int64_t>::value, 
+                "is_comparable_int<int8_t, int64_t> is broken");
 
   uint8_t u8_99 = 99;
   uint8_t u8_100 = 100;
@@ -80,23 +80,23 @@ int main()
 
 #if defined(HAVE_INT128_T)
 
-  static_assert(!is_comparable<uint128_t, double>::value, 
-                "is_comparable<uint128_t, double> is broken");
+  static_assert(!is_comparable_int<uint128_t, double>::value, 
+                "is_comparable_int<uint128_t, double> is broken");
 
-  static_assert(is_comparable<int128_t, int128_t>::value, 
-                "is_comparable<int128_t, int128_t> is broken");
+  static_assert(is_comparable_int<int128_t, int128_t>::value, 
+                "is_comparable_int<int128_t, int128_t> is broken");
 
-  static_assert(is_comparable<uint128_t, int128_t>::value, 
-                "is_comparable<uint128_t, int128_t> is broken");
+  static_assert(is_comparable_int<uint128_t, int128_t>::value, 
+                "is_comparable_int<uint128_t, int128_t> is broken");
 
-  static_assert(is_comparable<int128_t, int8_t>::value, 
-                "is_comparable<int128_t, int8_t> is broken");
+  static_assert(is_comparable_int<int128_t, int8_t>::value, 
+                "is_comparable_int<int128_t, int8_t> is broken");
 
-  static_assert(is_comparable<uint128_t, uint8_t>::value, 
-                "is_comparable<uint128_t, uint8_t> is broken");
+  static_assert(is_comparable_int<uint128_t, uint8_t>::value, 
+                "is_comparable_int<uint128_t, uint8_t> is broken");
 
-  static_assert(!is_comparable<int8_t, int128_t>::value, 
-                "is_comparable<int8_t, int128_t> is broken");
+  static_assert(!is_comparable_int<int8_t, int128_t>::value, 
+                "is_comparable_int<int8_t, int128_t> is broken");
 
   int128_t i128_99 = 99;
   int128_t i128_100 = 100;
